# xtssort
##### This is the ten method of list sorting.

>install
>>```sheel
>>pip install xtssort
>>```

```python
from xtssort import *

# Bubble_sorting
Bubble_sorting(lt=list,Positive_or_reverse_order=2 or 1)
# selectionSort
selectionSort(arr=list)
# insertionSort
insertionSort(arr=list)
# shellSort
shellSort(arr=list)
# mergeSort
mergeSort(arr=list)
# quickSort
quickSort(arr=list,left=,right=)
# heapSort
heapSort(arr=list)
# countingSort
countingSort(arr=list,maxValue=)
# bucket_sort
bucket_sort(arr=list,max_num=)
# radix_sort
radix_sort(data=list)
```